@@ -129,14 +129,21 @@ def create_department(data: dict) -> dict:
         return Resp(code=ServerErrorCode, msg=checked.errors)
     # 构造path
     parent_id = data.pop("parent_id")
-    parent = Department.objects.get(pk=parent_id)
-    if parent.organization_id != data["organization_id"]:
-        raise ValueError(f"organization_id:{data['organization_id']} different of parent organization_id: {parent.organization_id}")
-    if parent.path:
-        path = parent.path
-        path.append(parent.id)
+    if parent_id:
+        parent = Department.objects.get(pk=parent_id)
+        if parent.organization_id != data["organization_id"]:
+            raise ValueError(
+                f"organization_id:{data['organization_id']} different of parent organization_id: {parent.organization_id}")
+        if parent.path:
+            path = parent.path
+            path.append(parent.id)
+        else:
+            path = [parent.id]
     else:
-        path = [parent.id]
+        if Department.objects.filter(organization_id=data["organization_id"]).exists():
+            raise ValueError(f"organization: {data['organization_id']} already has a level-1 department")
+        path = []
+
     # 找到最大排序数
     show_order = Department.objects.aggregate(num=Max('show_order'))["num"]
     data["show_order"] = show_order + 1
