@@ -38,11 +38,15 @@ if __name__ == '__main__':
     # print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
     # print(obj.create({"name": "前端o99", "parent_id": 2}))
-    print(obj.retrieve(3))
+    # print(obj.retrieve(3))
     # print(obj.update(18, {"name": "前端99", "parent_id": 2, "charger_id": None}))
     # print(obj.delete(2))
     # print(obj.move_show_order({"department_id": 4, "type": "up"}))
     # print(obj.create_department_user(5, [1, 2, 3]))
     # print(obj.department_user_list(5,))
     # print(obj.delete_department_user(5, [11]))
-    # print(obj.get_chargers())
\ No newline at end of file
+    # print(obj.get_chargers())
+    # print(obj.organization_user_list())
+    # print(obj.exclude(5))
+    # print(obj.change(1, []))
+    # print(obj.user_departments(1))
